@@ -6,7 +6,7 @@ from __future__ import annotations
 
 import datetime
 from http import HTTPStatus
-from typing import BinaryIO
+from typing import Any, BinaryIO
 from urllib.parse import urljoin
 
 import requests
@@ -21,7 +21,6 @@ from vws.exceptions.cloud_reco_exceptions import (
     RequestTimeTooSkewed,
 )
 from vws.exceptions.custom_exceptions import (
-    ActiveMatchingTargetsDeleteProcessing,
     RequestEntityTooLarge,
 )
 from vws.include_target_data import CloudRecoIncludeTargetData
@@ -95,14 +94,12 @@ class CloudRecoService:
                 file in the grayscale or RGB color space.
             ~vws.exceptions.custom_exceptions.RequestEntityTooLarge: The given
                 image is too large.
-            ~vws.exceptions.custom_exceptions.ActiveMatchingTargetsDeleteProcessing:
-                The given image matches a target which was recently deleted.
 
         Returns:
             An ordered list of target details of matching targets.
         """
         image_content = _get_image_data(image=image)
-        body = {
+        body: dict[str, Any] = {
             "image": ("image.jpeg", image_content, "image/jpeg"),
             "max_num_results": (None, int(max_num_results), "text/plain"),
             "include_target_data": (
@@ -113,12 +110,7 @@ class CloudRecoService:
         }
         date = rfc_1123_date()
         request_path = "/v1/query"
-        (
-            content,
-            content_type_header,
-        ) = encode_multipart_formdata(  # type:ignore[no-untyped-call]
-            fields=body,
-        )
+        content, content_type_header = encode_multipart_formdata(fields=body)
         method = "POST"
 
         authorization_string = authorization_header(
@@ -153,9 +145,6 @@ class CloudRecoService:
         if "Integer out of range" in response.text:
             raise MaxNumResultsOutOfRange(response=response)
 
-        if "No content to map due to end-of-input" in response.text:
-            raise ActiveMatchingTargetsDeleteProcessing
-
         result_code = response.json()["result_code"]
         if result_code != "Success":
             exception = {
