@@ -5,15 +5,13 @@ Tools for interacting with Vuforia APIs.
 from __future__ import annotations
 
 import base64
-import io
 import json
+import time
 from datetime import date
-from time import sleep
+from typing import TYPE_CHECKING, BinaryIO
 from urllib.parse import urljoin
 
 import requests
-from func_timeout import func_set_timeout
-from func_timeout.exceptions import FunctionTimedOut
 from requests import Response
 from vws_auth_tools import authorization_header, rfc_1123_date
 
@@ -47,6 +45,17 @@ from vws.reports import (
     TargetSummaryReport,
 )
 
+if TYPE_CHECKING:
+    import io
+
+
+def _get_image_data(image: BinaryIO) -> bytes:
+    original_tell = image.tell()
+    image.seek(0)
+    image_data = image.read()
+    image.seek(original_tell)
+    return image_data
+
 
 def _target_api_request(
     server_access_key: str,
@@ -201,7 +210,7 @@ class VWS:
         self,
         name: str,
         width: int | float,
-        image: io.BytesIO,
+        image: BinaryIO,
         application_metadata: str | None,
         *,
         active_flag: bool,
@@ -252,7 +261,7 @@ class VWS:
                 occurred". This has been seen to happen when the given name
                 includes a bad character.
         """
-        image_data = image.getvalue()
+        image_data = _get_image_data(image=image)
         image_data_encoded = base64.b64encode(image_data).decode("ascii")
 
         data = {
@@ -321,44 +330,11 @@ class VWS:
             target_record=target_record,
         )
 
-    def _wait_for_target_processed(
-        self,
-        target_id: str,
-        seconds_between_requests: float,
-    ) -> None:
-        """
-        Wait indefinitely for a target to get past the processing stage.
-
-        Args:
-            target_id: The ID of the target to wait for.
-            seconds_between_requests: The number of seconds to wait between
-                requests made while polling the target status.
-
-        Raises:
-            ~vws.exceptions.vws_exceptions.AuthenticationFailure: The secret
-                key is not correct.
-            ~vws.exceptions.vws_exceptions.Fail: There was an error with the
-                request. For example, the given access key does not match a
-                known database.
-            TimeoutError: The target remained in the processing stage for more
-                than five minutes.
-            ~vws.exceptions.vws_exceptions.UnknownTarget: The given target ID
-                does not match a target in the database.
-            ~vws.exceptions.vws_exceptions.RequestTimeTooSkewed: There is an
-                error with the time sent to Vuforia.
-        """
-        while True:
-            report = self.get_target_summary_report(target_id=target_id)
-            if report.status != TargetStatuses.PROCESSING:
-                return
-
-            sleep(seconds_between_requests)
-
     def wait_for_target_processed(
         self,
         target_id: str,
         seconds_between_requests: float = 0.2,
-        timeout_seconds: float | None = 60 * 5,
+        timeout_seconds: float = 60 * 5,
     ) -> None:
         """
         Wait up to five minutes (arbitrary) for a target to get past the
@@ -372,8 +348,7 @@ class VWS:
                 decrease the number of calls made to the API, to decrease the
                 likelihood of hitting the request quota.
             timeout_seconds: The maximum number of seconds to wait for the
-                target to be processed. If ``None`` is given, no maximum is
-                applied.
+                target to be processed.
 
         Raises:
             ~vws.exceptions.vws_exceptions.AuthenticationFailure: The secret
@@ -389,19 +364,17 @@ class VWS:
             ~vws.exceptions.vws_exceptions.RequestTimeTooSkewed: There is an
                 error with the time sent to Vuforia.
         """
+        start_time = time.monotonic()
+        while True:
+            report = self.get_target_summary_report(target_id=target_id)
+            if report.status != TargetStatuses.PROCESSING:
+                return
 
-        # func_timeout does not have type hints.
-        @func_set_timeout(timeout=timeout_seconds)  # type: ignore[misc]
-        def decorated() -> None:
-            self._wait_for_target_processed(
-                target_id=target_id,
-                seconds_between_requests=seconds_between_requests,
-            )
+            elapsed_time = time.monotonic() - start_time
+            if elapsed_time > timeout_seconds:  # pragma: no cover
+                raise TargetProcessingTimeout
 
-        try:
-            decorated()
-        except FunctionTimedOut as exc:
-            raise TargetProcessingTimeout from exc
+            time.sleep(seconds_between_requests)
 
     def list_targets(self) -> list[str]:
         """
@@ -641,7 +614,7 @@ class VWS:
             data["width"] = width
 
         if image is not None:
-            image_data = image.getvalue()
+            image_data = _get_image_data(image=image)
             image_data_encoded = base64.b64encode(image_data).decode("ascii")
             data["image"] = image_data_encoded
 
